import FileIcons from '@/file-icons'

let fileIcons
beforeEach(() => {
  fileIcons = new FileIcons()
})

describe('FileIcons', async () => {
  test('getFileIcon', async () => {
    const data = {
      'file.py': 'python',
      '/long/path/readme.txt': 'book',
      'random-file.txt': 'file',
      'charmap.md': 'markdown',
      'tmux.conf': 'tmux'
    }
    for (const file of Object.keys(data)) {
      const expected = data[file]
      const icon = await fileIcons.getFileIcon(file)
      if (!expected) {
        expect(icon).not.toBeTruthy()
      } else {
        const { ref } = icon
        expect(ref).toEqual(expected)
      }
    }
  })

  test('Add and remove Rule', async () => {
    const idx = fileIcons.addRule([
      /.*\.txt/i,
      'octicons',
      'markdown',
      999,
      '#000'
    ])

    let icon = await fileIcons.getFileIcon('random-file.txt')
    expect(icon).toBeTruthy()

    const expected = {
      viewBox: expect.anything(),
      font: 'octicons',
      ref: 'markdown',
      path: expect.anything(),
      colour: '#000'
    }
    expect(icon).toMatchObject(expected)

    fileIcons.removeRule(idx)
    icon = await fileIcons.getFileIcon('random-file.txt')
    // Ensure the rule got removed and we're back to default icons
    expect(icon).not.toMatchObject(expected)
  })
})
